#[non_exhaustive]pub enum Answer {
Noul(NoulAnswer),
Choice(ChoiceAnswer),
Score(ScoreAnswer),
}Expand description
One answer, tagged with the type of the question that produced it.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Noul(NoulAnswer)
Answer to a Noul question.
Choice(ChoiceAnswer)
Answer to a Choice question.
Score(ScoreAnswer)
Answer to a Score question.
Implementations
Sourceimpl Answer
impl Answer
Sourcepub const fn as_noul(&self) -> Option<f64>
pub const fn as_noul(&self) -> Option<f64>
The yes-probability, if this answers a Noul question.
Sourcepub const fn as_choice(&self) -> Option<&ChoiceAnswer>
pub const fn as_choice(&self) -> Option<&ChoiceAnswer>
The choice answer, if this answers a Choice question.
Sourcepub const fn as_score(&self) -> Option<&ScoreAnswer>
pub const fn as_score(&self) -> Option<&ScoreAnswer>
The score answer, if this answers a Score question.