pub struct SystemOneResponse {
pub model: String,
pub answers: HashMap<String, Answer>,
pub usage: Usage,
}Expand description
Response from POST /v1/systemone.
Fields
model: StringThe versioned model id that answered, e.g. jev-1.13.0.
answers: HashMap<String, Answer>One answer per question, under the same keys.
usage: UsageToken accounting for this request.
Implementations
Sourceimpl SystemOneResponse
impl SystemOneResponse
Sourcepub fn noul(&self, id: &str) -> Result<f64>
pub fn noul(&self, id: &str) -> Result<f64>
The yes-probability of the Noul question id.
Errors
Error::MissingAnswer if there is no answer under id or it is not a Noul.
Sourcepub fn choice(&self, id: &str) -> Result<&ChoiceAnswer>
pub fn choice(&self, id: &str) -> Result<&ChoiceAnswer>
The answer to the Choice question id.
Errors
Error::MissingAnswer if there is no answer under id or it is not a Choice.
Sourcepub fn score(&self, id: &str) -> Result<&ScoreAnswer>
pub fn score(&self, id: &str) -> Result<&ScoreAnswer>
The answer to the Score question id.
Errors
Error::MissingAnswer if there is no answer under id or it is not a Score.